@@ -1,6 +1,6 @@
-#' @title Mann-Kendall Trend Test of Time series Data with out any modifications
+#' @title Mann-Kendall Trend Test of Time Series Data Without Modifications
 #'
-#' @description Mann-Kendall trend test is a non-parametric trend test used to identify monotonic trends present in time series data.
+#' @description The Mann-Kendall trend test is a nonparametric trend test used to identify monotonic trends present in time series data.
 #'
 #' @importFrom stats acf median pnorm qnorm
 #'
@@ -8,26 +8,25 @@
 #'
 #' @param  x  - Time series data vector
 #'
-#' @return  Z  - Mann- Kendall Z-statistic
+#' @return  Z  - Mann-Kendall Z statistic
 #'
-#' sen's slope  - sen's slope
+#' Sen's slope  - Sen's slope
 #'
-#' s  - Mann-Kendall 's'- statistic
+#' S  - Mann-Kendall S statistic
 #'
-#' Var(s) - Variance of 's'
+#' Var(s) - Variance of S
 #'
-#' P-value  - Mann-Kendall P-Value
+#' P-value  - Mann-Kendall p-value
 #'
 #' Tau  - Mann-Kendall's Tau
 #'
+#' @references Kendall, M. (1975). Rank Correlation Methods. Griffin, London, 202 pp.
 #'
-#' @references Mann, H. B. (1945). Nonparametric Tests Against Trend. Econometrica, 13(3), 245–259. <doi:10.1017/CBO9781107415324.004>.
+#' @references Mann, H. B. (1945). Nonparametric Tests Against Trend. Econometrica, 13(3): 245-259.
 #'
-#' @references Kendall, M. (1975). Multivariate analysis. Charles Griffin. Londres. 0-85264-234-2.
+#' @references Sen, P. K. (1968). Estimates of the Regression Coefficient Based on Kendall’s Tau. Journal of the American statistical Association, 63(324): 1379. <doi:10.2307/2285891>
 #'
-#' @references sen, P. K. (1968). Estimates of the Regression Coefficient Based on Kendall’s Tau. Journal of the American statistical Association, 63(324), 1379. <doi:10.2307/2285891>.
-#'
-#' @details Mann-Kendall trend test is a non-parametric trend tests which assuems no distribution of the data. Null hypothesis of the test is that there is no trend in the data and the alternate hypothesis is that the data represents a monotonic trend.
+#' @details The Mann-Kendall trend test is a nonparametric trend tests which assuems no distribution of the data. The null hypothesis of the test is that there is no trend in the data and the alternative hypothesis is that the data represents a monotonic trend.
 #'
 #' @examples x<-c(Nile)
 #' mkttest(x)
@@ -35,15 +34,15 @@
 #' @export
 #'
 mkttest <-function(x) {
-  # Initialize the test Parameters
+  # Initialize the test parameters
 
-  # Time-Series Vector
+  # Time series vector
   x = x
-  # Mann-Kendall Z-Statistic
+  # Mann-Kendall Z statistic
   z = NULL
-  # Mann-Kendall P-value
+  # Mann-Kendall p-value
   pval = NULL
-  # Mann-Kendall 'S'- Statistic
+  # Mann-Kendall S statistic
   S = 0
   # Mann-Kendall var.S
   var.S = NULL
@@ -64,8 +63,13 @@ mkttest <-function(x) {
   }
 
   n<-length(x)
+  
+  #Specify minimum input vector length
+  if (n < 3) {
+    stop("Input vector must contain at least three values")
+  }
 
-  # Calculating Mann-Kendall 'S'- Statistic
+  # Calculating Mann-Kendall S statistic
 
   for (i in 1:(n-1)) {
     for (j in (i+1):n) {
@@ -73,7 +77,7 @@ mkttest <-function(x) {
     }
   }
 
-  # Calculating Mann-Kendall Variance (Var(s))
+  # Calculating Mann-Kendall variance (Var(s))
 
   var.S = n*(n-1)*(2*n+5)*(1/18)
   if(length(unique(x)) < n) {
@@ -86,7 +90,7 @@ mkttest <-function(x) {
     }
   }
 
-  # Calculating Z-Statistic values
+  # Calculating Z statistic values
 
   if (S == 0) {
     z = 0
@@ -97,12 +101,12 @@ mkttest <-function(x) {
     z = (S+1)/sqrt(var.S)
   }
 
-  # Calculating P-Value
+  # Calculating p-value
 
   pval = 2*pnorm(-abs(z))
 
 
-  # Calculating kendall's Tau
+  # Calculating Kendall's Tau
 
   Tau = S/(.5*n*(n-1))
 
